SpanTraceStatus

Struct SpanTraceStatus 

pub struct SpanTraceStatus(/* private fields */);
The current status of a SpanTrace, indicating whether it was captured or whether it is empty for some other reason.

Implementations

Source

impl SpanTraceStatus

pub const UNSUPPORTED: SpanTraceStatus

Formatting a SpanTrace is not supported, likely because there is no ErrorLayer or the ErrorLayer is from a different version of tracing_error

pub const EMPTY: SpanTraceStatus

The SpanTrace is empty, likely because it was captured outside of any spans

pub const CAPTURED: SpanTraceStatus

A span trace has been captured and the SpanTrace should print reasonable information when rendered.